package artcustomer.limon.minko.api {
	import flash.display.DisplayObjectContainer;
	
	import artcustomer.framework.context.FlashContext;
	import artcustomer.framework.events.*;
	import artcustomer.framework.utils.consts.*;
	
	import artcustomer.limon.minko.layers.layer3d.ApplicationLayer3D;
	
	
	/**
	 * LimonMinko
	 * 
	 * @author David Massenot
	 */
	public class LimonMinko extends FlashContext {
		
		
		/**
		 * Constructor
		 */
		public function LimonMinko() {
			super();
			
			this.name = 'Limon Minko';
			this.mode = ContextMode.DEV;
		}
		
		//---------------------------------------------------------------------
		//  Events
		//---------------------------------------------------------------------
		
		/**
		 * @private
		 */
		private function listenEvents():void {
			this.addEventListener(ContextErrorEvent.ERROR, handleContextError, false, 0, true);
			this.addEventListener(ContextErrorEvent.FRAMEWORK_ERROR, handleContextError, false, 0, true);
			this.addEventListener(ContextErrorEvent.ILLEGAL_ERROR, handleContextError, false, 0, true);
		}
		
		/**
		 * @private
		 */
		private function unlistenEvents():void {
			this.removeEventListener(ContextErrorEvent.ERROR, handleContextError);
			this.removeEventListener(ContextErrorEvent.FRAMEWORK_ERROR, handleContextError);
			this.removeEventListener(ContextErrorEvent.ILLEGAL_ERROR, handleContextError);
		}
		
		//---------------------------------------------------------------------
		//  Listeners
		//---------------------------------------------------------------------
		
		/**
		 * @private
		 */
		private function handleContextError(e:ContextErrorEvent):void {
			var allowError:Boolean = true;
			var errorName:String = e.errorName +  ' ' + e.error.errorID;
			var errorText:String = '';
			
			switch (this.mode) {
				case(ContextMode.RELEASE):
					allowError = true;
					errorText = String(e.error.message);
					break;
					
				case(ContextMode.DEV):
					allowError = true;
					errorText = String(e.error.message);
					break;
					
				case(ContextMode.DEBUG):
					allowError = true;
					errorText = String(e.error.getStackTrace());
					break;
					
				default:
					allowError = false;
					break;
			}
			
			if (allowError) trace('ERROR - ' + errorName + ' : ' + errorText);
			
			e.stopPropagation();
		}
		
		//---------------------------------------------------------------------
		//  Layers3 
		//---------------------------------------------------------------------
		
		/**
		 * @private
		 */
		private function addDefaultLayer3D():void {
			this.addLayer3D(ApplicationLayer3D);
		}
		
		
		/**
		 * Setup Application. Entry point.
		 */
		override public function setup():void {
			listenEvents();
			
			super.setup();
			
			this.moveLogo(LogoPosition.BOTTOM_RIGHT, 5, 10);
			this.renderEngine.start();
			
			addDefaultLayer3D();
		}
		
		/**
		 * Destroy Application. Exit point.
		 */
		override public function destroy():void {
			unlistenEvents();
			
			super.destroy();
		}
	}
}