package artcustomer.limon.minko.layers.layer3d.scenes {
	import artcustomer.framework.engines.layers.tools.scene.AbstractScene3D;
	import artcustomer.framework.extensions.minko.template.MinkoTemplate;
	
	import aerys.minko.render.geometry.stream.StreamUsage;
	import aerys.minko.type.animation.SkinningMethod;
	import aerys.minko.type.loader.ILoader;
	import aerys.minko.type.loader.TextureLoader;
	import aerys.minko.type.loader.parser.ParserOptions;
	import aerys.minko.type.parser.collada.ColladaParser;
	
	
	/**
	 * SceneAstroBoy
	 * 
	 * @author David Massenot
	 */
	public class SceneAstroBoy extends AbstractScene3D {
		[Embed(source="../../../../../../../bin/assets/seymour/astroboy.dae", mimeType="application/octet-stream")]
		private static const DAE : Class;
		
		[Embed (source="../../../../../../../bin/assets/seymour/boy_10.jpg")]
		private static const TEXTURE : Class;
		
		private var _template:MinkoTemplate;
		
		private var _options:ParserOptions;
		
		
		/**
		 * Constructor
		 */
		public function SceneAstroBoy() {
			super();
		}
		
		//---------------------------------------------------------------------
		//  Options
		//---------------------------------------------------------------------
		
		/**
		 * @private
		 */
		private function setupOptions():void {
			_options = new ParserOptions();
			_options.parser	= ColladaParser;
			_options.mipmapTextures = true;
			_options.dependencyLoaderFunction = loadDependency;
			_options.vertexStreamUsage = StreamUsage.READ;
			_options.skinningMethod	= SkinningMethod.HARDWARE_DUAL_QUATERNION;
			
			_template.scene.loadClass(DAE, _options);
		}
		
		/**
		 * @private
		 */
		private function destroyOptions():void {
			if (_options) _options = null;
		}
		
		/**
		 * @private
		 */
		private function loadDependency(dependencyPath:String, isTexture:Boolean, options:ParserOptions):ILoader {
			var loader : ILoader = new TextureLoader(_options.mipmapTextures);
			loader.loadClass(TEXTURE);
			
			return loader;
		}
		
		
		/**
		 * Setup Scene.
		 */
		override public function setup():void {
			super.setup();
			
			_template = this.layer3D.getTemplate() as MinkoTemplate;
			_template.controller.distance = 15;
			_template.controller.distanceStep = 0.02;
			_template.controller.lookAt.set(0, 3, 0);
			
			setupOptions();
		}
		
		/**
		 * Destroy Scene.
		 */
		override public function destroy():void {
			destroyOptions();
			
			_template = null;
			
			super.destroy();
		}
		
		/**
		 * Render Scene.
		 */
		override public function render():void {
			super.render();
		}
	}
}